@@ -1,6 +1,6 @@
 package Langertha::Role::OpenAICompatible;
 # ABSTRACT: Role for OpenAI-compatible API format
-our $VERSION = '0.301';
+our $VERSION = '0.302';
 use Moose::Role;
 use File::ShareDir::ProjectDistDir qw( :all );
 use Carp qw( croak );
@@ -36,10 +36,13 @@ sub default_image_model { 'gpt-image-1' }
 
 # Dynamic model listing
 
+sub list_models_path { '/models' }
+
+
 sub list_models_request {
   my ($self) = @_;
   return $self->generate_http_request(
-    GET => $self->url.'/v1/models',
+    GET => $self->url.$self->list_models_path,
     sub { $self->list_models_response(shift) },
   );
 }
@@ -333,7 +336,7 @@ Langertha::Role::OpenAICompatible - Role for OpenAI-compatible API format
 
 =head1 VERSION
 
-version 0.301
+version 0.302
 
 =head1 SYNOPSIS
 
@@ -408,12 +411,21 @@ when an API key is configured. Skipped when C<api_key> is C<undef>
 Returns the OpenAI OpenAPI spec file path used for request generation.
 Override in an engine to use a provider-specific spec (e.g., Mistral).
 
+=head2 list_models_path
+
+    my $path = $engine->list_models_path;
+
+Returns the path appended to C<url> for the models endpoint.
+Default: C</models>. Override in engines whose API spec uses a
+different path (e.g. Mistral uses C</v1/models> because its base URL
+does not include C</v1>).
+
 =head2 list_models_request
 
     my $request = $engine->list_models_request;
 
-Generates an HTTP GET request for the C</v1/models> endpoint.
-Returns an HTTP request object.
+Generates an HTTP GET request for the models endpoint using
+C<list_models_path>. Returns an HTTP request object.
 
 =head2 list_models_response
 
